<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Session;
use App\Helpers\EncryptDecrypt;
use App\Traits\ConsumeExternalService;
use App\Helpers\s3upload;

class CardController extends Controller
{
   
    use ConsumeExternalService;


    public function personal_card()
    {
        return view('user.card.personal_card');
    }

    public function create_personal_card()
    {
        
        $loginUserData = Session::get('login_user_data');
        $userToken = Session::get('user_token');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];


        $card_response = $this->performRequest("POST", "/v1/card/Home", null, $formParams);
        $card_response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($card_response));

        // dd($card_response_decoded);

        $avatarId = Session::get('id');
        $requestUri = "/v1/user_auth/avatar_list";
        $response = $this->performRequest("GET", $requestUri, []);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);
        if($card_response_decoded->code != 0){
        if($card_response_decoded->data->create_card_step == 1){
            return redirect()->route('add_location');
        }else{
            return view('user.card.create_personal',compact('response_decoded','avatarId'));
        }
        }else{
            return view('user.card.create_personal',compact('response_decoded','avatarId'));
        }

    }

    public function personal_card_post(Request $request)
    {

        $loginUserData = Session::get('login_user_data');
        $userToken = Session::get('user_token');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];


        if($request->user_type != 'C'){

                $post_data = array(
                    'user_type'=>'P',
                    'name'=>$request->name,
                    'country_code'=> $request->country_code,
                    'mobile_number' => $request->mobile_number,
                    'email' =>  $request->email,
                    'designation' => $request->designation,
                    'company_name' => $request->company_name,
                    'date_of_birth' => $request->dob,   
                );

                if ($request->has('image')) {
                    $file = $request->file('image');
                    $imageName = $file->getClientOriginalName();
                    $tmpFile = $file->getRealPath();
                    $path = env('AWS_BUCKET_FOLDER') . env('PROFILE_IMAGES');
                    $contents = s3upload::uploadImage($imageName, $tmpFile, $path);
                    $post_data['profile_image'] = $contents;
                    $post_data['avatar_id'] = 0;
                }
            
                if ($request->avatar_id != null) {
                    $avatarId = $request->avatar_id;
                    $post_data['avatar_id'] = $avatarId;
                    $post_data['profile_image'] = null;
                }

                if ($request->has('company_logo')) {
                    $file = $request->file('company_logo');
                    $imageName = $file->getClientOriginalName();
                    $tmpFile = $file->getRealPath();
                    $path = env('AWS_BUCKET_FOLDER') . env('COMPANY_LOGO');
                    $contents = s3upload::uploadImage($imageName, $tmpFile, $path);
                    $post_data['company_logo'] = $contents;
                }

                // dd($post_data);
        }else{

            $post_data = array(
                'user_type'=>'C',
                'name'=>$request->name,
                'country_code'=> $request->country_code,
                'mobile_number' => $request->mobile_number,
                'email' =>  $request->email,
                'designation' => $request->designation,
            );

            if ($request->has('business_logo')) {
                $file = $request->file('business_logo');
                $imageName = $file->getClientOriginalName();
                $tmpFile = $file->getRealPath();
                $path = env('AWS_BUCKET_FOLDER') . env('COMPANY_LOGO');
                $contents = s3upload::uploadImage($imageName, $tmpFile, $path);
                $post_data['business_logo'] = $contents;
            }

            // dd($post_data);

        }

        $data1 = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/v1/card/add_card", $data1, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);
        if ($response_decoded->code == 1) {  
            return redirect()->route('add_location');
        }else{
            return redirect()->back()->with('error', $response_decoded->message);

        }
    }

    public function add_location()
    {

        $loginUserData = Session::get('login_user_data');
        $userToken = Session::get('user_token');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];


        $card_response = $this->performRequest("POST", "/v1/card/Home", null, $formParams);
        $card_response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($card_response));

       
        if($card_response_decoded->code != 0){
        if($card_response_decoded->data->location_step == 1){
            return redirect()->route('add_social_media');
        }else{

            return view('user.card.add_location');
        }
    }else{
        return view('user.card.add_location');
    }
    }

    public function add_location_post(Request $request)
    {

        $loginUserData = Session::get('login_user_data');
        $userToken = Session::get('user_token');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];



        $post_data = array(
            'is_location_skip'=>'0',
            'address'=>$request->address,
            'latitude'=> $request->latitude,
            'longitude' => $request->longitude,
            
        );

        // dd($post_data);

        $data1 = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/v1/card/add_location", $data1, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        // dd($response_decoded);


        if ($response_decoded->code == 1) {  
            return redirect()->route('add_social_media');
        }else{
            return redirect()->back()->with('error', $response_decoded->message);

        }
    }

    public function add_social_media()
    {

        $loginUserData = Session::get('login_user_data');
        $userToken = Session::get('user_token');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];


        $card_response = $this->performRequest("POST", "/v1/common/socialAccounts", null, $formParams);
        $card_response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($card_response));

        $social_media =  $card_response_decoded;
        // dd($card_response_decoded);

        return view('user.card.add_social',compact('social_media'));
    }


    public function social_media_post(Request $request)
    {

        $loginUserData = Session::get('login_user_data');
        $userToken = Session::get('user_token');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];




        $post_data = array(
            'social' => array(
                array(
                    'social_platform_id' => $request->social_platform_id,
                    'link' => $request->link,
                )
            )
        );
        

        // dd($post_data);

        $data1 = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/v1/card/add_socialAccount", $data1, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        // dd($response_decoded);


        if ($response_decoded->code == 1) {  
            return redirect()->route('home');
        }else{
            return redirect()->back()->with('error', $response_decoded->message);

        }
    }

    

    public function edit_personal_card()
    { 

        $loginUserData = Session::get('login_user_data');
        $userToken = Session::get('user_token');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];

        $avatarId = Session::get('id');
        $requestUri = "/v1/user_auth/avatar_list";
        $response = $this->performRequest("GET", $requestUri, []);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);


        $homedatarequestUri = "/v1/card/Home";

        $homedata_response = $this->performRequest("POST", $homedatarequestUri,null, $formParams);

        $homedata_response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($homedata_response));
        $homeData = $homedata_response_decoded;

        // dd($homeData);

        $companyLogoFilename = basename($homeData->data->company_logo);
        

        return view('user.card.edit_personal_card',compact('response_decoded','homeData','companyLogoFilename'));
    }


    public function edit_personal_card_post(Request $request)
    { 

        $loginUserData = Session::get('login_user_data');
        $userToken = Session::get('user_token');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];


        if($request->user_type != 'C'){

                $post_data = array(
                    'user_type'=>'P',
                    'name'=>$request->name,
                    'country_code'=> $request->country_code,
                    'mobile_number' => $request->mobile_number,
                    'email' =>  $request->email,
                    'designation' => $request->designation,
                    'company_name' => $request->company_name,
                    'date_of_birth' => $request->dob,   
                );

                if ($request->has('image')) {
                    $file = $request->file('image');
                    $imageName = $file->getClientOriginalName();
                    $tmpFile = $file->getRealPath();
                    $path = env('AWS_BUCKET_FOLDER') . env('PROFILE_IMAGES');
                    $contents = s3upload::uploadImage($imageName, $tmpFile, $path);
                    $post_data['profile_image'] = $contents;
                    $post_data['avatar_id'] = 0;
                }
            
                if ($request->avatar_id != null) {
                    $avatarId = $request->avatar_id;
                    $post_data['avatar_id'] = $avatarId;
                    $post_data['profile_image'] = null;
                }

                if ($request->has('company_logo')) {
                    $file = $request->file('company_logo');
                    $imageName = $file->getClientOriginalName();
                    $tmpFile = $file->getRealPath();
                    $path = env('AWS_BUCKET_FOLDER') . env('COMPANY_LOGO');
                    $contents = s3upload::uploadImage($imageName, $tmpFile, $path);
                    $post_data['company_logo'] = $contents;
                }

                // dd($post_data);
        }else{

            $post_data = array(
                'user_type'=>'C',
                'name'=>$request->name,
                'country_code'=> $request->country_code,
                'mobile_number' => $request->mobile_number,
                'email' =>  $request->email,
                'designation' => $request->designation,
            );

            if ($request->has('business_logo')) {
                $file = $request->file('business_logo');
                $imageName = $file->getClientOriginalName();
                $tmpFile = $file->getRealPath();
                $path = env('AWS_BUCKET_FOLDER') . env('COMPANY_LOGO');
                $contents = s3upload::uploadImage($imageName, $tmpFile, $path);
                $post_data['business_logo'] = $contents;
            }

            // dd($post_data);

        }

        $data1 = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/v1/card/edit_card", $data1, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);
        if ($response_decoded->code == 1) {  
            return redirect()->route('edit_location');
        }else{
            return redirect()->back()->with('error', $response_decoded->message);

        }
    }



    public function edit_business_card()
    { 

        $loginUserData = Session::get('login_user_data');
        $userToken = Session::get('user_token');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];

        $avatarId = Session::get('id');
        $requestUri = "/v1/user_auth/avatar_list";
        $response = $this->performRequest("GET", $requestUri, []);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);


        $homedatarequestUri = "/v1/card/Home";

        $homedata_response = $this->performRequest("POST", $homedatarequestUri,null, $formParams);

        $homedata_response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($homedata_response));
        $homeData = $homedata_response_decoded;

        // dd($homeData);

        $companyLogoFilename = basename($homeData->data->company_logo);
        

        return view('user.card.edit_business_card',compact('response_decoded','homeData','companyLogoFilename'));
    }



    public function edit_location()
    {

        return view('user.card.edit_location');
    }


    public function edit_location_post(Request $request)
    {

        $loginUserData = Session::get('login_user_data');
        $userToken = Session::get('user_token');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];



        $post_data = array(
            'is_location_skip'=>'0',
            'address'=>$request->address,
            'latitude'=> $request->latitude,
            'longitude' => $request->longitude,
            
        );

        // dd($post_data);

        $data1 = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/v1/card/edit_location_details", $data1, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        // dd($response_decoded);


        if ($response_decoded->code == 1) {  
            return redirect()->route('edit_social');
        }else{
            return redirect()->back()->with('error', $response_decoded->message);

        }
    }



    public function edit_social()
    {
        $loginUserData = Session::get('login_user_data');
        $userToken = Session::get('user_token');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];

        $homedatarequestUri = "/v1/card/Home";

        $homedata_response = $this->performRequest("POST", $homedatarequestUri,null, $formParams);

        $homedata_response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($homedata_response));
        $homeData = $homedata_response_decoded;

        // dd($homeData);


        $card_response = $this->performRequest("POST", "/v1/common/socialAccounts", null, $formParams);
        $card_response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($card_response));

        $social_media =  $card_response_decoded;
        // dd($card_response_decoded);

        return view('user.card.edit_social_media',compact('social_media','homeData'));
    }




    public function edit_social_post(Request $request)
    {

        $loginUserData = Session::get('login_user_data');
        $userToken = Session::get('user_token');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];




        $post_data = array(
            'social' => array(
                array(
                    'social_platform_id' => $request->social_platform_id,
                    'social_media_account_link' => $request->link,
                )
            )
        );
        

        // dd($post_data);

        $data1 = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/v1/card/edit_social_account_details", $data1, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        // dd($response_decoded);


        if ($response_decoded->code == 1) {  
            return redirect()->route('home');
        }else{
            return redirect()->back()->with('error', $response_decoded->message);

        }
    }


    // ----------------------------------------------------Business card----------------------------------------------



    public function business_card()
    {
        $loginUserData = Session::get('login_user_data');
        // dd($loginUserData);



        return view('user.card.business_card');
    }



    public function business_info()
    {
        $loginUserData = Session::get('login_user_data');
        $userToken = Session::get('user_token');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];


        $card_response = $this->performRequest("POST", "/v1/card/Home", null, $formParams);
        $card_response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($card_response));

        // dd($card_response_decoded);
        if($card_response_decoded->code != 0){
            if($card_response_decoded->data->create_card_step == 1){
                return redirect()->route('add_location');
            }else{
    
                return view('user.card.add_businessinfo');
            }

        }else{
            return view('user.card.add_businessinfo');
        }
    }

}
