<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\admin\CardModel;
use App\admin\UserModel;
use DataTables;

class CardController extends Controller
{

    //================================== Display Cards ==========================
    public function cards(Request $request)
    {
        //dd('hello');
        if ($request->ajax()) {
            //$data = CardModel::where("is_delete", 0)->orderBy('insert_date', 'desc')->get();
            $data = CardModel::with('user')->where('is_delete', 0)->orderBy('insert_date', 'desc')->get()->toArray();
            // dd($data);

            // return response()->json(['data' => $data]);
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($data) {
                    $btn = '<a href="' . url('admin/card-view/' . $data['id']) . '/' . $data['user_type'] . '" class="view btn btn_color btn-sm"><i class="md md-remove-red-eye"></i></a> ';
                    $btn .= '<a href="' . url('admin/card-edit/' . $data['id']) . '/' . $data['user_type'] . '" class="edit btn btn_color btn-sm"><i class="md md-mode-edit"></i></a> ';
                    $btn .= '<a href="" class="del_btn btn btn_color btn-sm del_btn" id="' . $data['id'] . '"><i class="md md-delete"></i></a>';
                    return $btn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.pages.card');
    }
    //================================= Search User===========================
    public function serachUser(Request $request)
    {
        $name = $request->input('term');
        $user = UserModel::where('is_delete', 0)
            ->where(function ($query) use ($name) {
                $query->where('full_name', 'LIKE', "%$name%")
                    ->orWhere('business_name', 'LIKE', "%$name%");
            })
            ->get();
        if ($user) {
            return response()->json(['status' => 'success', 'data' => $user]);
        } else {
            return response()->json(['status' => 'error'], 404);
        }
        //return view('admin.pages.cardadd', compact('user'));
    }
    //================================= Add Card ==============================
    public function addCard()
    {
        return view('admin.pages.cardadd');
    }

    public function addCardData(Request $req)
    {
        //dd($req->file('image'));
        if ($req->input('card-type') == 'personal') {
            $validationRules = [
                'name' => 'required',
                'userid' => 'required',
                'email' => 'required|email|unique:tbl_card',
                'country_code' => 'required|numeric',
                'mobile_number' => 'required|numeric|unique:tbl_card',
                'company' => 'required',
                'designation' => 'required',
                'image' => 'required|image|mimes:jpeg,png,jpg,gif|max:5120',
            ];
        } else {
            $validationRules = [
                'business-name' => 'required',
                'userid' => 'required',
                'email' => 'required|unique:tbl_card',
                'country_code' => 'required|numeric',
                'phone_number' => 'required|numeric|unique:tbl_card',
                'address' => 'required',
                'designation' => 'required',
                'image' => 'required|image|mimes:jpeg,png,jpg,gif|max:5120',
            ];
        }

        $req->validate($validationRules, [
            'name.required' => 'Enter User Fullname',
            'userid.required' => 'Enter User ID',
            'email.required' => 'Enter Email Address',
            'email.unique' => 'Email Address already exists',
            'email.email' => 'Enter Valide Email Address',
            'country_code.required' => 'Enter Country Code',
            'country_code.numeric' => 'Country Code must be numeric',
            'mobile_number.required' => 'Enter Phone Number',
            'mobile_number.numeric' => 'Phone Number must be numeric',
            'mobile_number.unique' => 'Phone Number already exists',
            'company.required' => 'Enter Company Name',
            'business-name.required' => 'Enter Business Name',
            'user_type.required' => 'Select User Type',
            'address.required' => 'Enter Card Address',
            'designation.required' => 'Enter Designation',
            'image.required' => 'Upload Image',
            'image.mimes' => 'Image must be of type: jpeg, png, jpg, gif',
            'image.max' => 'Image size must not exceed 5MB',
        ]);

        $userid = $req->input('userid');
        $name = $req->input('fullname');
        $country_code = $req->input('country_code');
        $mobile_number = $req->input('mobile_number');
        $email = $req->input('email');
        $dob = $req->input('dob');
        $designation = $req->input('designation');
        $address = $req->input('address');
        $company = $req->input('company');
        $business = $req->input('business-name');
        $image = $req->file('image');

        $imageName = time() . '.' . $image->getClientOriginalExtension();
        $image->move(public_path('assets/admin/upload'), $imageName);

        // if ($req->hasfile('image')) {
        //     $file = $req->file('image');
        //     $name = time() . $file->getClientOriginalName();
        //     $filePath = 'images/' . $name;
        //     //  Storage::disk('s3')->put($filePath, file_get_contents($file));
        //     return back()->with('success', 'Image Uploaded successfully');
        // }

        if ($req->input('card-type') == 'personal') {
            $data = CardModel::create([
                'user_id' => $userid,
                'user_type' => 'P',
                'country_code' => $country_code,
                'mobile_number' => $mobile_number,
                'email' => $email,
                'date_of_birth' => $dob,
                'name' => $name,
                'profile_image' => $imageName,
                'company_name' => $company,
                'designation' => $designation,
            ]);
        } else {
            $data = CardModel::create([
                'company_name' => $req->input('business-name'),
                'user_type' => 'C',
                'country_code' => $country_code,
                'mobile_number' => $mobile_number,
                'address' => $req->input('address'),
                'designation' => $req->input('designation'),
            ]);
        }
        //dd($data->id);
        // return Response::json(array('success' => true), 200);

        return response()->json(['status' => 'success', 'message' => 'Card Created Successfully']);
    }
    //======================== View Card ==================================
    public function viewCard($id)
    {
        //dd($id);
        $data = CardModel::where('is_delete', 0)->where('id', $id)->first();
        // dd($data);
        return view('admin.pages.cardview', compact('data'));
    }

    //======================== Edit Card =================================
    public function editCard($id)
    {
        $data = CardModel::where('is_delete', 0)->where('id', $id)->first();

        return view('admin.pages.cardedit', compact('data'));
    }

    public function updateCard(Request $req)
    {
        if ($req->input('card-type') == 'P') {
            $validationRules = [
                'name' => 'required',
                'userid' => 'required',
                'email' => 'required|email',
                'country_code' => 'required|numeric',
                'mobile_number' => 'required|numeric',
                'dob' => 'required|date',
                'company' => 'required',
                'designation' => 'required',
            ];
        } else {
            $validationRules = [
                'business-name' => 'required',
                'userid' => 'required',
                'email' => 'required|email',
                'country_code' => 'required|numeric',
                'mobile_number' => 'required|numeric',
                'address' => 'required',
                'designation' => 'required',
            ];
        }
        $req->validate($validationRules, [
            'name.required' => 'Enter User Fullname',
            'userid.required' => 'Enter User ID',
            'email.required' => 'Enter Email Address',
            'email.email' => 'Enter Valide Email Address',
            'email.unique' => 'Email Address already exists',
            'country_code.required' => 'Enter Country Code',
            'country_code.numeric' => 'Country Code must be numeric',
            'mobile_number.required' => 'Enter Phone Number',
            'mobile_number.numeric' => 'Phone Number must be numeric',
            'mobile_number.unique' => 'Phone Number already exists',
            'company.required' => 'Enter Company Name',
            'business-name.required' => 'Enter Business Name',
            'address.required' => 'Enter Card Address',
            'designation.required' => 'Enter Designation',
        ]);

        if ($req->hasFile('image')) {
            $validationRules['image'] = 'image|mimes:jpeg,png,jpg,gif|max:2048';
        }

        $card = CardModel::find($req->input('userid'));



        if ($req->input('card-type') == 'P') {

            if ($req->hasFile('image')) {
                $image = $req->file('image');
                $imageName = time() . '.' . $image->getClientOriginalExtension();
                $image->move(public_path('assets/admin/upload'), $imageName);
                $card->profile_image = $imageName;
            }
            $card->name = $req['name'];
            $card->email = $req['email'];
            $card->country_code = $req['country_code'];
            $card->mobile_number = $req['mobile_number'];
            $card->email = $req['email'];
            $card->company_name = $req['company'];
            $card->designation = $req['designation'];

        } else {
            if ($req->hasFile('image')) {
                $image = $req->file('image');
                $imageName = time() . '.' . $image->getClientOriginalExtension();
                $image->move(public_path('assets/admin/upload'), $imageName);
                $card->business_logo = $imageName;
            }

            $card->company_name = $req['business-name'];
            $card->email = $req['email'];
            $card->country_code = $req['country_code'];
            $card->mobile_number = $req['mobile_number'];
            $card->email = $req['email'];
            $card->designation = $req['designation'];
        }

        $card->save();
        return response()->json(['status' => 'success', 'message' => 'Card Update Successfully']);
    }

    //============================ Chnage Status ====================================
    public function statusCard(request $req)
    {
        $data = CardModel::find($req->input('id'));
        if ($data) {
            $data->is_active = ($req->input('status') == '0') ? '1' : '0';
            $data->save();

            $data = CardModel::where('is_delete', 0)->where('id', $req->input('id'))->get();

            return response()->json(['status' => 'success', 'data' => $data]);
        } else {
            return response()->json(['status' => 'error'], 404);
        }
    }

    //================================ Delete User ==================================
    public function deleteCard(request $req)
    {
        //dd($req->input('id'));
        $user = CardModel::find($req->input('id'));

        if ($user) {
            $user->is_delete = '1';
            $user->save();
            return response()->json(['status' => 'success']);
        }

        return response()->json(['status' => 'error', 'message' => 'Food not found.'], 404);
    }




}
